@@ -27,6 +27,7 @@ from typing import Dict, Iterator, List, Optional, Tuple
 from ..analysis import get_lucene_analyzer, JAnalyzer, JAnalyzerUtils
 from ..pyclass import autoclass, JString
 from ..search import Document
+from pyserini.util import download_prebuilt_index, get_indexes_info
 
 logger = logging.getLogger(__name__)
 
@@ -50,6 +51,7 @@ class JIndexHelpers:
 
 
 class JGenerators(Enum):
+    AclAnthologyGenerator = autoclass('io.anserini.index.generator.AclAnthologyGenerator')
     DefaultLuceneDocumentGenerator = autoclass('io.anserini.index.generator.DefaultLuceneDocumentGenerator')
     TweetGenerator = autoclass('io.anserini.index.generator.TweetGenerator')
     WapoGenerator = autoclass('io.anserini.index.generator.WashingtonPostGenerator')
@@ -149,6 +151,28 @@ class IndexReader:
         self.object = JIndexReader()
         self.reader = self.object.getReader(JString(index_dir))
 
+    @classmethod
+    def from_prebuilt_index(cls, prebuilt_index_name: str):
+        """Build an index reader from the prebuilt index, download the index if necessary.
+
+        Parameters
+        ----------
+        prebuilt_index_name : str
+            Prebuilt index name.
+
+        Returns
+        -------
+        IndexReader
+            Index reader built from the prebuilt index.
+        """
+        index_dir = download_prebuilt_index(prebuilt_index_name)
+        return cls(index_dir)
+
+    @staticmethod
+    def list_prebuilt_indexes():
+        """Display available prebuilt indexes' information."""
+        get_indexes_info()
+
     def analyze(self, text: str, analyzer=None) -> List[str]:
         """Analyze a piece of text. Applies Anserini's default Lucene analyzer if analyzer not specified.
 
@@ -260,6 +284,30 @@ class IndexReader:
             doc_vector_dict[term] = doc_vector_map.get(JString(term.encode('utf-8')))
         return doc_vector_dict
 
+    def get_term_positions(self, docid: str) -> Optional[Dict[str, int]]:
+        """Return the term position mapping of the document with ``docid``. Note that the term in the document is
+        stemmed and stop words may be removed according to your index settings. Also, requesting the document vector of
+        a ``docid`` that does not exist in the index will return ``None`` (as opposed to an empty dictionary); this
+        forces the caller to handle ``None`` explicitly and guards against silent errors.
+
+        Parameters
+        ----------
+        docid : str
+            Collection ``docid``.
+
+        Returns
+        -------
+        Optional[Dict[str, int]]
+            A tuple contains a dictionary with analyzed terms as keys and corresponding posting list as values
+        """
+        java_term_position_map = self.object.getTermPositions(self.reader, JString(docid))
+        if java_term_position_map is None:
+            return None
+        term_position_map = {}
+        for term in java_term_position_map.keySet().toArray():
+            term_position_map[term] = java_term_position_map.get(JString(term.encode('utf-8'))).toArray()
+        return term_position_map
+
     def doc(self, docid: str) -> Optional[Document]:
         """Return the :class:`Document` corresponding to ``docid``. Returns ``None`` if the ``docid`` does not exist
         in the index.
