@@ -26,6 +26,7 @@ from ._base import Document, JQuery, JQueryGenerator
 from pyserini.pyclass import autoclass, JString, JArrayList
 from pyserini.trectools import TrecRun
 from pyserini.fusion import FusionMethod, reciprocal_rank_fusion
+from pyserini.util import download_prebuilt_index, get_indexes_info
 
 logger = logging.getLogger(__name__)
 
@@ -45,9 +46,39 @@ class SimpleSearcher:
     """
 
     def __init__(self, index_dir: str):
+        self.index_dir = index_dir
         self.object = JSimpleSearcher(JString(index_dir))
         self.num_docs = self.object.getTotalNumDocuments()
 
+    @classmethod
+    def from_prebuilt_index(cls, prebuilt_index_name: str):
+        """Build a searcher from the pre-built index; download the index if necessary.
+
+        Parameters
+        ----------
+        prebuilt_index_name : str
+            Prebuilt index name.
+
+        Returns
+        -------
+        SimpleSearcher
+            Searcher built from the prebuilt index.
+        """
+        print(f'Attempting to initialize pre-built index {prebuilt_index_name}.')
+        try:
+            index_dir = download_prebuilt_index(prebuilt_index_name)
+        except ValueError:
+            print(f'Unknown pre-built index: {prebuilt_index_name}')
+            return None
+
+        print(f'Initializing {prebuilt_index_name}...')
+        return cls(index_dir)
+
+    @staticmethod
+    def list_prebuilt_indexes():
+        """Display available prebuilt indexes' information."""
+        get_indexes_info()
+
     def search(self, q: Union[str, JQuery], k: int = 10, query_generator: JQueryGenerator = None, strip_segment_id=False, remove_dups=False) -> List[JSimpleSearcherResult]:
         """Search the collection.
 
